/******************************************************************************/
/* Sistemas Integrados TECNISA                                                */
/* Nome: 0005_DENSTPO_USR_EXPORTAAF_DENADAI.sql                               */
/*                                                                            */
/* Descrio:                                                                 */
/* Procedure destinada a possibilitar que as autorizaes de fornecimento     */
/* (AF's) geradas pelo sistema da Teknisa sejam importadas no sistema da      */
/* Microsiga e, para isso, a procedure alimentar duas tabelas intermedirias */
/* entre os dois sistemas                                                     */
/* (tabelas pertencentes ao banco de dados do sistema da Microsiga).          */
/* Criao:                                                                   */
/* 29/07/2008 - Raquel Cunha                                                  */
/******************************************************************************/

CREATE OR REPLACE
PROCEDURE USR_EXPORTAAF_DENADAI IS
   V_DTGRV         DATE;
   V_HRGRV         VARCHAR2(04);

   V_FILIAL        VARCHAR(10);
   V_FORMPGTO      VARCHAR(3);

   V_NUM6          INTEGER;
   V_NRSEQ         VARCHAR(03);

  V_NOVOCODIGO     INTEGER;
  V_NRCONTADOR     INT;
BEGIN
   V_DTGRV := NULL;
   V_HRGRV := NULL;

   V_NRSEQ := '001';

   /* Retorna data e hora de exportao */
   BEGIN
      SELECT TO_DATE(SYSDATE), TO_CHAR(SYSDATE,'HH24MI')
        INTO V_DTGRV, V_HRGRV
        FROM DUAL;
   EXCEPTION
      WHEN NO_DATA_FOUND THEN
         V_DTGRV := NULL;
         V_HRGRV := NULL;
   END;

   V_NRCONTADOR := 0;

   FOR C_AFEXPORT IN
      (SELECT A.CDFILDEST, A.CDFILLANC, A.NRAUTOFORN,
              A.DTAUTOFORN, A.CDFORNECED, A.VRTOTALAF,
              SUBSTR(replace(replace(replace(F.NRINSJURFORN, '-', ''),'.',''),'/',''),1,14) AS NRINSJURFORN
         FROM AUTOFORNE A, FORNECEDOR F, FILIAL FI,
              (SELECT DISTINCT(CDFILIAL)
                 FROM FILGRUPFILI
                WHERE USR_IDPROTHEUS = 'S') FG
        WHERE NVL(A.USR_IDEXPORTA, 'S') = 'S'
          AND A.USR_DTEXPORTA IS NULL
          AND A.CDFORNECED = F.CDFORNECED
          AND FI.CDFILIAL = A.CDFILDEST
          AND FI.CDFILIAL = FG.CDFILIAL
          AND FI.CDEMPRESA = '05'
        ORDER BY A.CDFILDEST, A.CDFILLANC, A.NRAUTOFORN
       )
   LOOP
      SELECT MAX(CDGRUPFILI)
        INTO V_FILIAL
        FROM FILGRUPFILI
       WHERE CDFILIAL = C_AFEXPORT.CDFILLANC
         AND USR_IDPROTHEUS = 'S';

      IF NOT V_FILIAL IS NULL THEN

         /* Verifica existncia da AF */
         SELECT NVL(MAX(W6_IDAFPVC),0)
           INTO V_NUM6
           FROM USR_ZW6
          WHERE CDFILDEST  = C_AFEXPORT.CDFILDEST
            AND CDFILLANC  = C_AFEXPORT.CDFILLANC
            AND NRPEDEXOL  = C_AFEXPORT.NRAUTOFORN
            AND ORIGPEDIDO = 'A'
            AND W6_TPEDI   = '1';

         /* Retorna o sequencial para a tabela */
         BEGIN
            SELECT W6_IDAFPVC.NEXTVAL
              INTO V_NOVOCODIGO
              FROM DUAL;
         EXCEPTION
            WHEN NO_DATA_FOUND THEN
               V_NOVOCODIGO := 1;
         END;

         /* Se nao possui a AF sera incluido um novo registro */
         IF V_NUM6 = 0 THEN
            INSERT INTO USR_ZW6
                (CDFILDEST, CDFILLANC, NRPEDEXOL, W6_IDAFPVC,
                 W6_EMPRESA, W6_FILIAL, W6_NUM,
                 W6_CGC, W6_CC, W6_CONDPAG, W6_TIPO, W6_TPEDI, ORIGPEDIDO,
                 W6_DTGRV, W6_HRGRV, W6_DTIMP, W6_HRIMP)
            VALUES
                (C_AFEXPORT.CDFILDEST, C_AFEXPORT.CDFILLANC, C_AFEXPORT.NRAUTOFORN, V_NOVOCODIGO,
                 SUBSTR(V_FILIAL, 7, 2), SUBSTR(V_FILIAL, 9, 2), SUBSTR(C_AFEXPORT.NRAUTOFORN, 5, 6),
                 SUBSTR(C_AFEXPORT.NRINSJURFORN, 1, 14), C_AFEXPORT.CDFILDEST, V_FORMPGTO, 'N', '1', 'A',
                 V_DTGRV, V_HRGRV, NULL, '');
         ELSE
            INSERT INTO USR_ZW6
                (CDFILDEST, CDFILLANC, NRPEDEXOL, W6_IDAFPVC,
                 W6_EMPRESA, W6_FILIAL, W6_NUM,
                 W6_CGC, W6_CC, W6_CONDPAG, W6_TIPO, W6_TPEDI, ORIGPEDIDO,
                 W6_DTGRV, W6_HRGRV, W6_DTIMP, W6_HRIMP)
            VALUES
                (C_AFEXPORT.CDFILDEST, C_AFEXPORT.CDFILLANC, C_AFEXPORT.NRAUTOFORN, V_NOVOCODIGO,
                 SUBSTR(V_FILIAL, 7, 2), SUBSTR(V_FILIAL, 9, 2), SUBSTR(C_AFEXPORT.NRAUTOFORN, 5, 6),
                 SUBSTR(C_AFEXPORT.NRINSJURFORN, 1, 14), C_AFEXPORT.CDFILDEST, V_FORMPGTO, 'N', '2', 'A',
                 V_DTGRV, V_HRGRV, NULL, '');

            FOR C_ITEXCL IN (SELECT CDPRODUTO, DTPROGENPEOL,
                                    W7_EMPRESA, W7_FILIAL, W7_NUM,
                                    W7_CGC, W7_ITEM, W7_PRODUTO, W7_CC, W7_QTDVEN,
                                    W7_PRCVEN, W7_PRUNIT, W7_VALOR, DTPROGENTAF
                               FROM USR_ZW7
                              WHERE CDFILDEST  = C_AFEXPORT.CDFILDEST
                                AND CDFILLANC  = C_AFEXPORT.CDFILLANC
                                AND NRPEDEXOL  = C_AFEXPORT.NRAUTOFORN
                                AND W7_IDAFPVI = V_NUM6
                              ORDER BY CDPRODUTO, DTPROGENTAF) LOOP

               INSERT INTO USR_ZW7
                    (CDFILDEST, CDFILLANC, NRPEDEXOL, CDPRODUTO,
                     W7_IDAFPVI, W7_EMPRESA, W7_FILIAL, W7_NUM,
                     W7_CGC, W7_ITEM, W7_PRODUTO, W7_CC, W7_QTDVEN,
                     W7_PRCVEN, W7_PRUNIT, W7_VALOR, W7_DTENTR, W7_TPEDI, DTPROGENTAF,
                     W7_DTGRV, W7_HRGRV, W7_DTIMP, W7_HRIMP)
               VALUES
                    (C_AFEXPORT.CDFILDEST, C_AFEXPORT.CDFILLANC, C_AFEXPORT.NRAUTOFORN, C_ITEXCL.CDPRODUTO,
                     V_NOVOCODIGO, C_ITEXCL.W7_EMPRESA, C_ITEXCL.W7_FILIAL, C_ITEXCL.W7_NUM,
                     C_ITEXCL.W7_CGC, C_ITEXCL.W7_ITEM, C_ITEXCL.W7_PRODUTO, C_ITEXCL.W7_CC, C_ITEXCL.W7_QTDVEN,
                     C_ITEXCL.W7_PRCVEN, C_ITEXCL.W7_PRUNIT, C_ITEXCL.W7_VALOR, C_ITEXCL.DTPROGENTAF, '2', C_ITEXCL.DTPROGENTAF,
                     V_DTGRV, V_HRGRV, NULL, '');
            END LOOP;

            /* Retorna o sequencial para a tabela */
            BEGIN
               SELECT W6_IDAFPVC.NEXTVAL
                 INTO V_NOVOCODIGO
                 FROM DUAL;
            EXCEPTION
               WHEN NO_DATA_FOUND THEN
                  V_NOVOCODIGO := 1;
            END;

            INSERT INTO USR_ZW6
                (CDFILDEST, CDFILLANC, NRPEDEXOL, W6_IDAFPVC,
                 W6_EMPRESA, W6_FILIAL, W6_NUM,
                 W6_CGC, W6_CC, W6_CONDPAG, W6_TIPO, W6_TPEDI, ORIGPEDIDO,
                 W6_DTGRV, W6_HRGRV, W6_DTIMP, W6_HRIMP)
            VALUES
                (C_AFEXPORT.CDFILDEST, C_AFEXPORT.CDFILLANC, C_AFEXPORT.NRAUTOFORN, V_NOVOCODIGO,
                 SUBSTR(V_FILIAL, 7, 2), SUBSTR(V_FILIAL, 9, 2), SUBSTR(C_AFEXPORT.NRAUTOFORN, 5, 6),
                 SUBSTR(C_AFEXPORT.NRINSJURFORN, 1, 14), C_AFEXPORT.CDFILDEST, V_FORMPGTO, 'N', '1', 'A',
                 V_DTGRV, V_HRGRV, NULL, '');
         END IF;

         FOR C_ITEMAUTF IN
            (SELECT P.CDARVPROD, I.CDPRODUTO, CDMARCA, DTPROGENTAF,
                    ROUND(QTPROGENTAF,2) AS QTPROGENTAF, ROUND(VRPREUNIAF,2) AS VRPREUNIAF, DTENTRITMSOL
               FROM ITEMAUTF I, PRODUTO P
              WHERE CDFILDEST = C_AFEXPORT.CDFILDEST
                AND CDFILLANC = C_AFEXPORT.CDFILLANC
                AND NRAUTOFORN = C_AFEXPORT.NRAUTOFORN
                AND I.CDPRODUTO = P.CDPRODUTO
              ORDER BY CDMARCA, I.CDPRODUTO, DTPROGENTAF
            )
         LOOP
            INSERT INTO USR_ZW7
                 (CDFILDEST, CDFILLANC, NRPEDEXOL, CDPRODUTO,
                  W7_IDAFPVI, W7_EMPRESA, W7_FILIAL, W7_NUM,
                  W7_CGC, W7_ITEM, W7_PRODUTO, W7_CC, W7_QTDVEN,
                  W7_PRCVEN, W7_PRUNIT, W7_VALOR, W7_TPEDI, DTPROGENTAF,
                  W7_DTGRV, W7_HRGRV, W7_DTIMP, W7_HRIMP)
            VALUES
                 (C_AFEXPORT.CDFILDEST, C_AFEXPORT.CDFILLANC, C_AFEXPORT.NRAUTOFORN, C_ITEMAUTF.CDPRODUTO,
                  V_NOVOCODIGO, SUBSTR(V_FILIAL, 7, 2), SUBSTR(V_FILIAL, 9, 2), SUBSTR(C_AFEXPORT.NRAUTOFORN, 5, 6),
                  SUBSTR(C_AFEXPORT.NRINSJURFORN, 1, 14), V_NRSEQ, SUBSTR(C_ITEMAUTF.CDARVPROD, 1, 15), C_AFEXPORT.CDFILDEST, C_ITEMAUTF.QTPROGENTAF,
                  C_ITEMAUTF.VRPREUNIAF, C_ITEMAUTF.VRPREUNIAF, (C_ITEMAUTF.QTPROGENTAF*C_ITEMAUTF.VRPREUNIAF),  '1', C_ITEMAUTF.DTPROGENTAF,
                  V_DTGRV, V_HRGRV, NULL, '');

            V_NRSEQ := LPAD(RTRIM(TO_CHAR(TO_NUMBER(RTRIM(V_NRSEQ))+ 1)),3,'0');
         END LOOP;

         UPDATE ITEMAUTF
            SET IDBAIXITMAF = '2'
          WHERE CDFILDEST  = C_AFEXPORT.CDFILDEST
            AND CDFILLANC  = C_AFEXPORT.CDFILLANC
            AND NRAUTOFORN = C_AFEXPORT.NRAUTOFORN;

         UPDATE AUTOFORNE
            SET USR_IDEXPORTA = 'N',
                USR_DTEXPORTA = SYSDATE,
                IDBAIXAAF = '2'
          WHERE CDFILDEST  = C_AFEXPORT.CDFILDEST
            AND CDFILLANC  = C_AFEXPORT.CDFILLANC
            AND NRAUTOFORN = C_AFEXPORT.NRAUTOFORN;

         V_NRSEQ := '001';

         V_NRCONTADOR := V_NRCONTADOR + 1;

         IF V_NRCONTADOR = 200 THEN
            V_NRCONTADOR := 0;
            COMMIT;
         END IF;
      END IF;
   END LOOP;
   COMMIT;
END;
/

-- VERSAO --
BEGIN ATUVEROBJ('USR_EXPORTAAF_DENADAI','5.80.XXX'); END;
/
